Generate a deterministic qualitative color sequence
Source:R/palette-generate.R
sc_palette_generate.RdExtends an optional fixed set without changing its colors. Candidates are ranked by their worst CIE2000 separation under normal, deutan, protan, and tritan simulations. The result is diagnostic and is not a guarantee of universal color-vision-deficiency safety.
Examples
sc_palette_generate(6, seed_colors = c("#0072B2", "#D55E00"))
#> [1] "#0072B2" "#D55E00" "#00DCC6" "#8B4D49" "#FFA270" "#BCADFF"